@@ -199,7 +199,7 @@ class Updatable(Resource):
         return cls._from_dict(response)
 
     @classmethod
-    def _update_certs(cls, id: str, **data) -> Resource:
+    def _update_certs(cls, id: str, files:Any , data) -> Resource:
         """Update an specific resource with new data.
 
         Performs a PUT request with the updated data.
@@ -211,8 +211,7 @@ class Updatable(Resource):
             Resource: The updated resource.
 
         """
-        response = client.put(f'/{cls._resource}/{id}/certificate',data)
-        print(response)
+        response = client.certs(f'/{cls._resource}/{id}/certificate', data, files)
         return cls._from_dict(response)
 
 
